#!/bin/bash


# Text modifiers
bold=$(tput bold)      # ${bold}
normal=$(tput sgr0)    # ${normal}
yellow=$(tput setaf 3) # ${yellow}

zenity --info --title='Please pick a folder!' --text='Choose a folder!' --width='300' --height='100'

# Folder variable
FOLDER=$(zenity  --file-selection --title="Choose a backup directory" --directory)
if [[ $? -eq 1 ]]; then
   echo You did not pick a ${bold}${yellow}folder.${normal} Exiting!
   exit 1
   else
   echo Backups will be saved into: ${bold}${yellow}$FOLDER${normal}
fi


# Options input
user_choice=$(zenity --list --checklist --width='600' --height='400' \
  --title="Backup script by RavePriest1" \
  --text="Select from the options below" \
  --column="Select" --column="Name" \
  FALSE "BACKUP All of My Data and Settings" \
  FALSE "RESTORE All of My Data and Settings")
if [[ $? -eq 1 ]]; then
   echo You did not pick an ${bold}${yellow}option.${normal} Exiting!
   exit 1
fi


if [[ $user_choice = *"BACKUP All of My Data and Settings"* ]]; then
  echo
  echo -----------------------------------------------------
  echo Copying ${bold}${yellow}$USER Settings and Files${normal} into ${bold}${yellow}$FOLDER/${normal}

  # GNOME SECTION
  dconf dump / > $FOLDER/$USER-ui
  # HU lang
  rsync -ap --info=progress2 /home/$USER/Asztal/ $FOLDER/
  rsync -ap --info=progress2 /home/$USER/Dokumentumok/ $FOLDER/
  rsync -ap --info=progress2 /home/$USER/Letöltések/ $FOLDER/
  rsync -ap --info=progress2 /home/$USER/Zenék/ $FOLDER/
  rsync -ap --info=progress2 /home/$USER/Képek/ $FOLDER/
  rsync -ap --info=progress2 /home/$USER/Videók/ $FOLDER/
  # EN lang
  rsync -ap --info=progress2 /home/$USER/Desktop/ $FOLDER/
  rsync -ap --info=progress2 /home/$USER/Documents/ $FOLDER/
  rsync -ap --info=progress2 /home/$USER/Downloads/ $FOLDER/
  rsync -ap --info=progress2 /home/$USER/Music/ $FOLDER/
  rsync -ap --info=progress2 /home/$USER/Pictures/ $FOLDER/
  rsync -ap --info=progress2 /home/$USER/Videos/ $FOLDER/
  
  rsync -ap --info=progress2 /home/$USER/Games/ $FOLDER/
  rsync -ap --info=progress2 /home/$USER/.librewolf/ $FOLDER/

  rsync -ap --info=progress2 --relative /home/$USER/.config/Bitwarden $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/heroic $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/input-remapper-2 $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/Mumble $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/libvirt $FOLDER/.config/
  sudo rsync -ap --info=progress2 --relative /etc/libvirt $FOLDER/etc/
  rsync -ap --info=progress2 --relative /home/$USER/.config/corectrl $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/corectrl.ini $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/vivaldi $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/BraveSoftware $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/FreeTube $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/dosbox-x $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/pavucontrol.ini $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/keepassxc $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/spotify $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/spotube $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/qBittorrent $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/kdeglobals $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/kdenliverc $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/kdenlive-layoutsrc $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/Signal $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/discord $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/Vencord $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/goverlay $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/MangoHud $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/easyeffects $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/mc $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/doublecmd $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/monophony $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/pamac $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/kdeconnect $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/Helvum $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/calibre $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.config/ $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.local/share/gnome-shell $FOLDER/.local/share
  rsync -ap --info=progress2 --relative /home/$USER/.local/share/flatpak/overrides/ $FOLDER/.local/share/flatpak/
  rsync -ap --info=progress2 --relative /home/$USER/.local/share/lutris $FOLDER/.local/share/
  rsync -ap --info=progress2 --relative /home/$USER/.local/share/TelegramDesktop $FOLDER/.local/share/
  
  rsync -ap --info=progress2 --relative /home/$USER/.steam/ $FOLDER/
  rsync -ap --info=progress2 --relative /home/$USER/.var/app/ $FOLDER/.var/app/
  sudo rsync -ap --info=progress2 --relative /usr/share/jellyfin/web/config.json $FOLDER/usr/share/jellyfin/web/

  konsave -s raveui-kde -f
  rsync -ap --info=progress2 --relative /home/$USER/.config/konsave $FOLDER/.config/
  rsync -ap --info=progress2 --relative /home/$USER/.local/state/dolphinstaterc $FOLDER/.local/state/

  echo ${bold}${yellow}$USER settings copied. ${normal}
  echo -----------------------------------------------------
  sudo chown -R $USER:$GROUP $FOLDER
  echo
fi

if [[ $user_choice = *"Restore all of my data and settings"* ]]; then
  echo
  echo -----------------------------------------------------
  echo Copying ${bold}${yellow}Restoring $USER Settings and Files ${normal} into ${bold}${yellow}$FOLDER/${normal}
  
  rsync -ap --info=progress2 $FOLDER /home/$USER/
  sudo rsync -ap --info=progress2 $FOLDER/etc/libvirt /etc/
  sudo rsync -ap --info=progress2 --relative $FOLDER/usr/share/jellyfin/web/config.json /usr/share/jellyfin/web/
  dconf load / < $FOLDER/$USER-ui
  konsave -a raveui-kde

  echo -----------------------------------------------------
  sudo chown -R $USER:$GROUP /home/$USER/
  echo
  echo ${bold}${yellow}$USER settings RESTORED! ${normal}
fi

exit